==> medapay-0.1.2.tar.gz: lib/src/screen/medapay_boa.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:medapay/src/components/preloader.dart';
import 'package:medapay/src/entity/medapay_bill_info.dart';
import 'package:medapay/src/entity/medapay_error.dart';
import 'package:medapay/src/service/medapay_service.dart';
import 'package:webview_flutter/webview_flutter.dart';

class MedaPayBOAScreen extends StatefulWidget {
  final MedaPayService service;
  final String referenceNumber;
  final Function onBillInfo;

  const MedaPayBOAScreen(
      {Key key, this.service, this.referenceNumber, this.onBillInfo})
      : super(key: key);

  @override
  _MedaPayBOAScreenState createState() => _MedaPayBOAScreenState();
}

class _MedaPayBOAScreenState extends State<MedaPayBOAScreen> {
  bool isLoading = true;
  bool navigatedToBill = false;
  MedaPayError error = null;
  MedaPayBillInfo billInfo = null;

  _fetchBillInfo() async {
    setState(() {
      isLoading = true;
    });
    try {
      var response = await widget.service.fetchBill(widget.referenceNumber);
      setState(() {
        isLoading = false;
      });
      if (response.statusCode == HttpStatus.ok) {
        var decodeBody = jsonDecode(response.body);
        MedaPayBillInfo info = MedaPayBillInfo.fromDecodedBody(decodeBody);
        widget.onBillInfo(billInfo);
        setState(() {
          billInfo = info;
          isLoading = false;
        });
      }
    } catch (e) {}
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      // onWillPop: () async => false,
      child: Scaffold(
        appBar: AppBar(
          title: Image.asset(
              'packages/medapay/assets/images/medapay-appbar-logo.png',
              fit: BoxFit.cover),
          backgroundColor: Color(0xfff56a05),
          leading: Container(),
          centerTitle: true,
        ),
        body: Container(
            child: Stack(
          children: [
            WebView(
              javascriptMode: JavascriptMode.unrestricted,
              gestureNavigationEnabled: true,
              gestureRecognizers: <Factory<OneSequenceGestureRecognizer>>{
                Factory<VerticalDragGestureRecognizer>(
                  () => VerticalDragGestureRecognizer(),
                ),
              },
              onWebViewCreated: (WebViewController webViewController) {
                Map<String, String> headers = {
                  "Authorization": "Bearer " + widget.service.getAuthToken(),
                  "x-access-from": "mobile-app"
                };
                webViewController.loadUrl(
                    "${widget.service.getUrl()}dp/boa/${widget.referenceNumber}",
                    headers: headers);
              },
              navigationDelegate: (NavigationRequest request) async {
                var requestUri = Uri.parse(request.url);
                if (requestUri.toString().contains("cybersource.com")) {
                  setState(() {
                    navigatedToBill = true;
                  });
                }
                if (requestUri.toString().contains("/api/boa/receipt")) {
                  await _fetchBillInfo();
                  return NavigationDecision.prevent;
                }
                return NavigationDecision.navigate;
              },
              onPageStarted: (url) {
                // setState(() {
                //   isLoading = true;
                // });
              },
              onPageFinished: (url) {
                if (navigatedToBill) {
                  Future.delayed(Duration(seconds: 2), () async {
                    setState(() {
                      isLoading = false;
                    });
                  });
                }
              },
            ),
            isLoading
                ? Positioned(
                    top: 0,
                    bottom: 0,
                    right: 0,
                    left: 0,
                    child: Container(
                      color: Color(0x50FFFFFF),
                      child: Center(
                          child: Preloader(
                        title: "Loading",
                        subtitle: "Loading please wait...",
                      )),
                    ))
                : billInfo != null
                    ? Positioned(
                        top: 0,
                        bottom: 0,
                        right: 0,
                        left: 0,
                        child: Container(
                          color: Color(0x50FFFFFF),
                          child: Center(
                              child: Preloader(
                            title: "Loading",
                            subtitle: "Loading please wait...",
                          )),
                        ))
                    : Container()
          ],
        )),
      ),
    );
  }
}

==> medapay-0.1.3.tar.gz: lib/src/screen/medapay_boa.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:flutter/foundation.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:medapay/src/components/preloader.dart';
import 'package:medapay/src/entity/medapay_bill_info.dart';
import 'package:medapay/src/entity/medapay_error.dart';
import 'package:medapay/src/service/medapay_service.dart';
import 'package:webview_flutter/webview_flutter.dart';

class MedaPayBOAScreen extends StatefulWidget {
  final MedaPayService service;
  final String referenceNumber;
  final Function onBillInfo;
  final String completedRoute;
  final String cancelRoute;
  final String errorRoute;

  const MedaPayBOAScreen(
      {Key key,
      this.service,
      this.referenceNumber,
      this.onBillInfo,
      this.completedRoute,
      this.cancelRoute,
      this.errorRoute})
      : super(key: key);

  @override
  _MedaPayBOAScreenState createState() => _MedaPayBOAScreenState();
}

class _MedaPayBOAScreenState extends State<MedaPayBOAScreen> {
  bool isLoading = true;
  bool navigatedToBill = false;
  MedaPayError error = null;
  MedaPayBillInfo billInfo = null;

  _fetchBillInfo(context) async {
    setState(() {
      isLoading = true;
    });
    try {
      var response = await widget.service.fetchBill(widget.referenceNumber);
      setState(() {
        isLoading = false;
      });
      if (response.statusCode == HttpStatus.ok) {
        var decodeBody = jsonDecode(response.body);
        MedaPayBillInfo info = MedaPayBillInfo.fromDecodedBody(decodeBody);
        widget.onBillInfo(billInfo);
        setState(() {
          billInfo = info;
          isLoading = false;
        });
        print("Attempting to push route ${widget.completedRoute}");
        Navigator.pushReplacementNamed(context, widget.completedRoute,
            arguments: billInfo);
      }
    } catch (e) {}
  }

  @override
  Widget build(BuildContext context) {
    return WillPopScope(
      // onWillPop: () async => false,
      child: Scaffold(
        appBar: AppBar(
          title: Image.asset(
              'packages/medapay/assets/images/medapay-appbar-logo.png',
              fit: BoxFit.cover),
          backgroundColor: Color(0xfff56a05),
          leading: Container(),
          centerTitle: true,
        ),
        body: Container(
            child: Stack(
          children: [
            WebView(
              javascriptMode: JavascriptMode.unrestricted,
              gestureNavigationEnabled: true,
              gestureRecognizers: <Factory<OneSequenceGestureRecognizer>>{
                Factory<VerticalDragGestureRecognizer>(
                  () => VerticalDragGestureRecognizer(),
                ),
              },
              onWebViewCreated: (WebViewController webViewController) {
                Map<String, String> headers = {
                  "Authorization": "Bearer " + widget.service.getAuthToken(),
                  "x-access-from": "mobile-app"
                };
                webViewController.loadUrl(
                    "${widget.service.getUrl()}dp/boa/${widget.referenceNumber}",
                    headers: headers);
              },
              navigationDelegate: (NavigationRequest request) async {
                var requestUri = Uri.parse(request.url);
                if (requestUri.toString().contains("cybersource.com")) {
                  setState(() {
                    navigatedToBill = true;
                  });
                }

                if (requestUri.toString().contains("/api/boa/receipt")) {
                  await _fetchBillInfo(context);
                  return NavigationDecision.prevent;
                }
                return NavigationDecision.navigate;
              },
              onPageStarted: (url) {
                // setState(() {
                //   isLoading = true;
                // });
              },
              onPageFinished: (url) {
                if (navigatedToBill) {
                  Future.delayed(Duration(seconds: 2), () async {
                    setState(() {
                      isLoading = false;
                    });
                  });
                }
              },
            ),
            isLoading
                ? Positioned(
                    top: 0,
                    bottom: 0,
                    right: 0,
                    left: 0,
                    child: Container(
                      color: Color(0x50FFFFFF),
                      child: Center(
                          child: Preloader(
                        title: "Loading",
                        subtitle: "Loading please wait...",
                      )),
                    ))
                : billInfo != null
                    ? Positioned(
                        top: 0,
                        bottom: 0,
                        right: 0,
                        left: 0,
                        child: Container(
                          color: Color(0x50FFFFFF),
                          child: Center(
                              child: Preloader(
                            title: "Loading",
                            subtitle: "Loading please wait...",
                          )),
                        ))
                    : Container()
          ],
        )),
      ),
    );
  }
}
